@@ -107,10 +107,12 @@
 #include "giostreamsink.h"
 #include "giostreamsrc.h"
 #include "identity.h"
+#include "inputselector.h"
 #include "multifdsink.h"
 #include "multiqueue.h"
 #include "oggdemux.h"
 #include "oggmux.h"
+#include "outputselector.h"
 #include "playbin2.h"
 #include "playbin.h"
 #include "queue.h"
@@ -129,6 +131,7 @@
 #include "timeoverlay.h"
 #include "typefindelement.h"
 #include "uridecodebin.h"
+#include "valve.h"
 #include "videorate.h"
 #include "videoscale.h"
 #include "videotestsrc.h"
@@ -191,6 +194,7 @@ GType gst_gio_stream_src_get_type(void);
 GType gst_identity_get_type(void);
 GType gst_index_get_type(void);
 GType gst_index_factory_get_type(void);
+GType gst_input_selector_get_type(void);
 GType gst_mixer_options_get_type(void);
 GType gst_mixer_track_get_type(void);
 GType gst_multi_fd_sink_get_type(void);
@@ -198,6 +202,7 @@ GType gst_multi_queue_get_type(void);
 GType gst_object_get_type(void);
 GType gst_ogg_demux_get_type(void);
 GType gst_ogg_mux_get_type(void);
+GType gst_output_selector_get_type(void);
 GType gst_pad_get_type(void);
 GType gst_pad_template_get_type(void);
 GType gst_pipeline_get_type(void);
@@ -230,6 +235,7 @@ GType gst_tuner_norm_get_type(void);
 GType gst_type_find_element_get_type(void);
 GType gst_type_find_factory_get_type(void);
 GType gst_uri_decode_bin_get_type(void);
+GType gst_valve_get_type(void);
 GType gst_video_rate_get_type(void);
 GType gst_video_scale_get_type(void);
 GType gst_video_sink_get_type(void);
@@ -302,6 +308,7 @@ namespace Gst {  class GioStreamSrc_Class { public: static Glib::ObjectBase* wra
 namespace Gst {  class Identity_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gst {  class Index_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gst {  class IndexFactory_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
+namespace Gst {  class InputSelector_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gst {  class MixerOptions_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gst {  class MixerTrack_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gst {  class MultiFdSink_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
@@ -309,6 +316,7 @@ namespace Gst {  class MultiQueue_Class { public: static Glib::ObjectBase* wrap_
 namespace Gst {  class Object_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gst {  class OggDemux_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gst {  class OggMux_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
+namespace Gst {  class OutputSelector_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gst {  class Pad_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gst {  class PadTemplate_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gst {  class Pipeline_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
@@ -341,6 +349,7 @@ namespace Gst {  class TunerNorm_Class { public: static Glib::ObjectBase* wrap_n
 namespace Gst {  class TypeFindElement_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gst {  class TypeFindFactory_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gst {  class UriDecodeBin_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
+namespace Gst {  class Valve_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gst {  class VideoRate_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gst {  class VideoScale_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gst {  class VideoSink_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
@@ -413,6 +422,7 @@ void wrap_init()
   Glib::wrap_register(gst_identity_get_type(), &Gst::Identity_Class::wrap_new);
   Glib::wrap_register(gst_index_get_type(), &Gst::Index_Class::wrap_new);
   Glib::wrap_register(gst_index_factory_get_type(), &Gst::IndexFactory_Class::wrap_new);
+  Glib::wrap_register(gst_input_selector_get_type(), &Gst::InputSelector_Class::wrap_new);
   Glib::wrap_register(gst_mixer_options_get_type(), &Gst::MixerOptions_Class::wrap_new);
   Glib::wrap_register(gst_mixer_track_get_type(), &Gst::MixerTrack_Class::wrap_new);
   Glib::wrap_register(gst_multi_fd_sink_get_type(), &Gst::MultiFdSink_Class::wrap_new);
@@ -420,6 +430,7 @@ void wrap_init()
   Glib::wrap_register(gst_object_get_type(), &Gst::Object_Class::wrap_new);
   Glib::wrap_register(gst_ogg_demux_get_type(), &Gst::OggDemux_Class::wrap_new);
   Glib::wrap_register(gst_ogg_mux_get_type(), &Gst::OggMux_Class::wrap_new);
+  Glib::wrap_register(gst_output_selector_get_type(), &Gst::OutputSelector_Class::wrap_new);
   Glib::wrap_register(gst_pad_get_type(), &Gst::Pad_Class::wrap_new);
   Glib::wrap_register(gst_pad_template_get_type(), &Gst::PadTemplate_Class::wrap_new);
   Glib::wrap_register(gst_pipeline_get_type(), &Gst::Pipeline_Class::wrap_new);
@@ -452,6 +463,7 @@ void wrap_init()
   Glib::wrap_register(gst_type_find_element_get_type(), &Gst::TypeFindElement_Class::wrap_new);
   Glib::wrap_register(gst_type_find_factory_get_type(), &Gst::TypeFindFactory_Class::wrap_new);
   Glib::wrap_register(gst_uri_decode_bin_get_type(), &Gst::UriDecodeBin_Class::wrap_new);
+  Glib::wrap_register(gst_valve_get_type(), &Gst::Valve_Class::wrap_new);
   Glib::wrap_register(gst_video_rate_get_type(), &Gst::VideoRate_Class::wrap_new);
   Glib::wrap_register(gst_video_scale_get_type(), &Gst::VideoScale_Class::wrap_new);
   Glib::wrap_register(gst_video_sink_get_type(), &Gst::VideoSink_Class::wrap_new);
@@ -512,6 +524,7 @@ void wrap_init()
   Gst::Identity::get_type();
   Gst::Index::get_type();
   Gst::IndexFactory::get_type();
+  Gst::InputSelector::get_type();
   Gst::MixerOptions::get_type();
   Gst::MixerTrack::get_type();
   Gst::MultiFdSink::get_type();
@@ -519,6 +532,7 @@ void wrap_init()
   Gst::Object::get_type();
   Gst::OggDemux::get_type();
   Gst::OggMux::get_type();
+  Gst::OutputSelector::get_type();
   Gst::Pad::get_type();
   Gst::PadTemplate::get_type();
   Gst::Pipeline::get_type();
@@ -551,6 +565,7 @@ void wrap_init()
   Gst::TypeFindElement::get_type();
   Gst::TypeFindFactory::get_type();
   Gst::UriDecodeBin::get_type();
+  Gst::Valve::get_type();
   Gst::VideoRate::get_type();
   Gst::VideoScale::get_type();
   Gst::VideoSink::get_type();
