@@ -136,11 +136,16 @@ int main (int argc, char *argv[])
             << get_plugin_defs("fdsrc", gst_type_is_a_pointer)
             << get_plugin_defs("filesrc", gst_type_is_a_pointer)
             << get_plugin_defs("filesink", gst_type_is_a_pointer)
+            << get_plugin_defs("funnel", gst_type_is_a_pointer)
             << get_plugin_defs("identity", gst_type_is_a_pointer)
+            << get_plugin_defs("input-selector", gst_type_is_a_pointer)
             << get_plugin_defs("multiqueue", gst_type_is_a_pointer)
+            << get_plugin_defs("output-selector", gst_type_is_a_pointer)
             << get_plugin_defs("queue", gst_type_is_a_pointer)
+            << get_plugin_defs("queue2", gst_type_is_a_pointer)
             << get_plugin_defs("tee", gst_type_is_a_pointer)
             << get_plugin_defs("typefind", gst_type_is_a_pointer)
+            << get_plugin_defs("valve", gst_type_is_a_pointer)
 
   // gst-plugins-base (GStreamer base) types:
             << get_defs(GST_TYPE_AUDIO_CLOCK, gst_type_is_a_pointer)
@@ -182,6 +187,7 @@ int main (int argc, char *argv[])
             << get_plugin_defs("appsrc", gst_type_is_a_pointer)
             << get_plugin_defs("appsink", gst_type_is_a_pointer)
             << get_plugin_defs("audioconvert", gst_type_is_a_pointer)
+            << get_plugin_defs("audiorate", gst_type_is_a_pointer)
             << get_plugin_defs("audioresample", gst_type_is_a_pointer)
             << get_plugin_defs("audiotestsrc", gst_type_is_a_pointer)
             << get_plugin_defs("cdparanoiasrc", gst_type_is_a_pointer)
@@ -202,6 +208,7 @@ int main (int argc, char *argv[])
             << get_plugin_defs("oggmux", gst_type_is_a_pointer)
             << get_plugin_defs("playbin", gst_type_is_a_pointer)
             << get_plugin_defs("playbin2", gst_type_is_a_pointer)
+            << get_plugin_defs("subtitleoverlay", gst_type_is_a_pointer)
             << get_plugin_defs("tcpclientsrc", gst_type_is_a_pointer)
             << get_plugin_defs("tcpclientsink", gst_type_is_a_pointer)
             << get_plugin_defs("tcpserversrc", gst_type_is_a_pointer)
